@@ -6,6 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
+use Log::Log4perl::Util;
 use Log::Log4perl::Logger;
 use Log::Log4perl::Level;
 use Log::Log4perl::Config;
@@ -13,7 +14,7 @@ use Log::Log4perl::Appender;
 
 use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '0.40';
+our $VERSION = '0.42';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -56,7 +57,6 @@ our $JOIN_MSG_ARRAY_CHAR = '';
     #and XML Config unit tests
 our $DOM_VERSION_REQUIRED = '1.29'; 
 
-
 ##################################################
 sub import {
 ##################################################
@@ -167,6 +167,13 @@ sub reset { # Mainly for debugging/testing
     return Log::Log4perl::Logger->reset();
 }
 
+##################################################
+sub init_once { # Call init only if it hasn't been
+                # called yet.
+##################################################
+    init(@_) unless $Log::Log4perl::Logger::INITIALIZED;
+}
+
 ##################################################
 sub init { # Read the config file
 ##################################################
@@ -462,7 +469,7 @@ we're using with a handle to the C<Logger>:
     }
 
 Instead, if a function/method wants a reference to the logger, it
-just calls the Logger's static C<get_logger()> method to obtain
+just calls the Logger's static C<get_logger($category)> method to obtain
 a reference to the I<one and only> possible logger object of
 a certain category.
 That's called a I<singleton> if you're a Gamma fan.
@@ -604,7 +611,16 @@ C<Log::Log4perl> already comes with a standard set of appenders:
     Log::Log4perl::Appender::DBI
     Log::Log4perl::Appender::Synchronized
 
-to log to the screen, to files and to databases.
+to log to the screen, to files and to databases. 
+
+On CPAN, you can find additional appenders like
+
+    Log::Log4perl::Layout::XMLLayout
+
+by Guido Carls E<lt>gcarls@cpan.orgE<gt>.
+It allows for hooking up Log::Log4perl with the graphical Log Analyzer
+Chainsaw (see 
+L<Log::Log4perl::FAQ/"Can I use Log::Log4perl with log4j's Chainsaw?">).
 
 =head2 Additional Appenders via Log::Dispatch
 
@@ -1122,6 +1138,40 @@ real class name as an argument and all other methods can determine it
 via C<ref($self)>), so it shouldn't be a problem to get the right class
 every time.
 
+=head2 Initialize once and only once
+
+It's important to realize that Log::Log4perl gets initialized once and only
+once, typically at the start of a program or system. Calling C<init()>
+more than once will cause it to clobber the existing configuration and
+I<replace> it by the new one.
+
+If you're in a traditional CGI environment, where every request is
+handeled by a new process, calling C<init()> every time is fine. In
+persistent environments like C<mod_perl>, however, Log::Log4perl
+should be initialized either at system startup time (Apache offers
+startup handlers for that) or via
+
+        # Init or skip if already done
+    Log::Log4perl->init_once($conf_file);
+
+C<init_once()> is identical to C<init()>, just with the exception
+that it will leave a potentially existing configuration alone and 
+will only call C<init()> if Log::Log4perl hasn't been initialized yet.
+
+If you're just curious if Log::Log4perl has been initialized yet, the
+
+    if(Log::Log4perl->initialized()) {
+        # Not initialized yet ...
+    }
+
+check can be used.
+
+If you're afraid that the components of your system are stepping on 
+each other's toes or if you are thinking that different components should
+initialize Log::Log4perl seperately, try to consolidate your system
+to use a centralized Log4perl configuration file and use 
+Log4perl's I<categories> to separate your components.
+
 =head1 Custom Filters
 
 Log4perl allows the use of customized filters in its appenders
@@ -1177,6 +1227,11 @@ C<Log::Log4perl> into the current namespace:
     use Log::Log4perl qw(get_logger);
     my $logger = get_logger();
 
+Please note this difference: To obtain the root logger, please use
+C<get_logger("")>, call it without parameters (C<get_logger()>), you'll
+get the logger of a category named after the current package. 
+C<get_logger()> is equivalent to C<get_logger(__PACKAGE__)>.
+
 =head2 Alternative initialization
 
 Instead of having C<init()> read in a configuration file, you can 
@@ -1231,7 +1286,7 @@ Instead of just statically initializing Log::Log4perl via
 there's a way to have Log::Log4perl periodically check for changes
 in the configuration and reload it if necessary:
 
-    Log::Log4perl->init($conf_file, $delay);
+    Log::Log4perl->init_and_watch($conf_file, $delay);
 
 In this mode, Log::Log4perl will examine the configuration file 
 C<$conf_file> every C<$delay> seconds for changes via the file's
@@ -1253,7 +1308,7 @@ To alleviate this performance hit a bit, C<init_and_watch()>
 can be configured to listen for a Unix signal to reload the 
 configuration instead:
 
-    Log::Log4perl->init($conf_file, 'HUP');
+    Log::Log4perl->init_and_watch($conf_file, 'HUP');
 
 This will set up a signal handler for SIGHUP and reload the configuration
 if the application receives this signal, e.g. via the C<kill> command:
@@ -2093,6 +2148,7 @@ our
     Chris R. Donnelly <cdonnelly@digitalmotorworks.com>
     James FitzGibbon <james.fitzgibbon@target.com>
     Paul Harrington <Paul-Harrington@deshaw.com>
+    David Hull <hull@paracel.com>
     Brett Rann <brettrann@mail.com>
     Erik Selberg <erik@selberg.com>
     Aaron Straup Cope <asc@vineyard.net>
@@ -2100,7 +2156,7 @@ our
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002 by Mike Schilli E<lt>m@perlmeister.comE<gt> and Kevin Goess
+Copyright 2002-2004 by Mike Schilli E<lt>m@perlmeister.comE<gt> and Kevin Goess
 E<lt>cpan@goess.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
